camelot.camelot.view.controls.tableview.TableView

Package camelot :: Package camelot :: Package view :: Package controls :: Module tableview :: Class TableView |
[hide private]
[frames] | no frames]

# Class TableView

source code

emits the row_selected signal when a row has been selected

Instance Methods | [hide private]
__init__(self, admin, search_text=None, parent=None) | source code
sectionClicked(self, section) emits a row_selected signal | source code
setSubclass(self, admin) Switch to a different subclass, where admin is the admin object of the subclass | source code
setCharts(self, charts) creates and display charts | source code
resizeColumnsAndRebuildQuery(self) resizes table of columns | source code
deleteSelectedRows(self) delete the selected rows in this tableview | source code
newRow(self) Create a new row in the tableview | source code
selectTableRow(self, row) selects the specified row | source code
selectedTableIndexes(self) returns a list of selected rows indexes | source code
getColumns(self) return the columns to be displayed in the table view | source code
getData(self) generator for data queried by table model | source code
getTitle(self) return the name of the entity managed by the admin attribute | source code
viewFirst(self) selects first row | source code
viewLast(self) selects last row | source code
viewNext(self) selects next row | source code
viewPrevious(self) selects previous row | source code
rebuildQuery(self) resets the table model query | source code
startSearch(self, text) rebuilds query based on filtering text | source code
cancelSearch(self) resets search filtering to default | source code
setFilters(self, items) sets filters for the tableview | source code
toHtml(self) generates html of the table | source code
closeEvent(self, event) reimplements close event | source code
__del__(self) deletes the tableview object | source code